@@ -1,5 +1,18 @@
+/* slaebz.f -- translated by f2c (version 20061008).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
+*/
+
 #include "clapack.h"
 
+
 /* Subroutine */ int slaebz_(integer *ijob, integer *nitmax, integer *n, 
 	integer *mmax, integer *minp, integer *nbmin, real *abstol, real *
 	reltol, real *pivmin, real *d__, real *e, real *e2, integer *nval, 
@@ -17,7 +30,7 @@
     integer itmp1, itmp2, kfnew, klnew;
 
 
-/*  -- LAPACK auxiliary routine (version 3.1) -- */
+/*  -- LAPACK auxiliary routine (version 3.2) -- */
 /*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
 /*     November 2006 */
 
