@@ -1,5 +1,18 @@
+/* ssyevr.f -- translated by f2c (version 20061008).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
+*/
+
 #include "clapack.h"
 
+
 /* Table of constant values */
 
 static integer c__10 = 10;
@@ -76,7 +89,7 @@ static integer c_n1 = -1;
 	    integer *, integer *);
 
 
-/*  -- LAPACK driver routine (version 3.1) -- */
+/*  -- LAPACK driver routine (version 3.2) -- */
 /*     Univ. of Tennessee, Univ. of California Berkeley and NAG Ltd.. */
 /*     November 2006 */
 
